IsCovered checks if a position is covered.
Note: filename in coverage profile might be relative or absolute depending on how test was run.
We assume simple matching for now.
type Report struct {
Total int Killed int Timeouts int Survived int Uncovered int BuildFailures int TestKills map[string][]string// test name -> list of mutation IDs}